summaryrefslogtreecommitdiff
path: root/iup/src/gtk/iupgtk_key.c
diff options
context:
space:
mode:
authorPixel <pixel@nobis-crew.org>2010-06-15 00:59:57 -0700
committerPixel <pixel@nobis-crew.org>2010-06-15 00:59:57 -0700
commiteed0eb6a476d54ce19aeff137984aa981d9e3976 (patch)
tree807891636efd2f87dcbd261e971216269973ae07 /iup/src/gtk/iupgtk_key.c
parentccc8261e4d48de89da4ddfe7b55e378ae0cd6f47 (diff)
Upgrading to iup 3.1
Diffstat (limited to 'iup/src/gtk/iupgtk_key.c')
-rwxr-xr-xiup/src/gtk/iupgtk_key.c26
1 files changed, 13 insertions, 13 deletions
diff --git a/iup/src/gtk/iupgtk_key.c b/iup/src/gtk/iupgtk_key.c
index 5aec919..ed485a7 100755
--- a/iup/src/gtk/iupgtk_key.c
+++ b/iup/src/gtk/iupgtk_key.c
@@ -316,9 +316,9 @@ gboolean iupgtkKeyPressEvent(GtkWidget *widget, GdkEventKey *evt, Ihandle *ih)
if (code == 0)
return FALSE;
- /* Avoid duplicate calls if a child of the dialog contains the focus.
- GTK will call the callback for the child and for the dialog */
- if (ih->iclass->nativetype == IUP_TYPEDIALOG && ih != IupGetFocus())
+ /* Avoid duplicate calls if a child of a native container contains the focus.
+ GTK will call the callback for the child and for the container. */
+ if (ih->iclass->childtype != IUP_CHILDNONE && ih != IupGetFocus())
return FALSE;
result = iupKeyCallKeyCb(ih, code);
@@ -390,33 +390,33 @@ gboolean iupgtkKeyReleaseEvent(GtkWidget *widget, GdkEventKey *evt, Ihandle *ih)
void iupgtkButtonKeySetStatus(guint state, unsigned int but, char* status, int doubleclick)
{
if (state & GDK_SHIFT_MASK)
- iupKEYSETSHIFT(status);
+ iupKEY_SETSHIFT(status);
if (state & GDK_CONTROL_MASK)
- iupKEYSETCONTROL(status);
+ iupKEY_SETCONTROL(status);
if ((state & GDK_BUTTON1_MASK) || but==1)
- iupKEYSETBUTTON1(status);
+ iupKEY_SETBUTTON1(status);
if ((state & GDK_BUTTON2_MASK) || but==2)
- iupKEYSETBUTTON2(status);
+ iupKEY_SETBUTTON2(status);
if ((state & GDK_BUTTON3_MASK) || but==3)
- iupKEYSETBUTTON3(status);
+ iupKEY_SETBUTTON3(status);
if ((state & GDK_BUTTON4_MASK) || but==4)
- iupKEYSETBUTTON4(status);
+ iupKEY_SETBUTTON4(status);
if ((state & GDK_BUTTON5_MASK) || but==5)
- iupKEYSETBUTTON5(status);
+ iupKEY_SETBUTTON5(status);
if (state & GDK_MOD1_MASK || state & GDK_MOD5_MASK) /* Alt */
- iupKEYSETALT(status);
+ iupKEY_SETALT(status);
if (state & GDK_MOD4_MASK) /* Apple/Win */
- iupKEYSETSYS(status);
+ iupKEY_SETSYS(status);
if (doubleclick)
- iupKEYSETDOUBLE(status);
+ iupKEY_SETDOUBLE(status);
}